function [pbd,p2d]=makePi_stripes(x,y,r1,Nd)
% function [pimatrix, d_index] = makePi_angles(x,y,radius,D)
% Input: 
%   x, y: M-by-N matrices storing the x and y coordinates 
%    of the points. All rows of x are the same. All columns 
%    of y are the same. x and y are thus as output from e.g.
%    function "meshgrid". 
% 
%   radius: radius of the detector circle. 
%   D: number of detectors
%
% Output: 
% pimatrix: the matrix pi, of size M-by-N-by-[D(D-1)/2]. 
%    for each position x and y (first two dimension) 
%    the matrix pi stores the probabilities of detection 
%    by particular pairs of detectors (third dimension).
% 
% Order of detector pairs is stored in the d_index which is  
% a 2-by-[D(D-1)/2] matrix. 
%
% Thus to e.g. display the matrix of probability of detections 
% for a particular position (10,15), you may use: 
%
% probs = pimatrix(10,15,:); 
% dets = zeros(D,D); 
% dets(sub2ind([D,D],d_index(1,:), d_index(2,:))) = probs; 
% dets = (dets + dets') /2;
% imagesc(dets);
% colorbar

 x=x-mean(x(:));
 y=y-mean(y(:));
 tubea=zeros(Nd,'single');
 tangles=single(-pi/2:pi/Nd:pi/2);
 tangles=tangles(1:end-1);
 for i=1:Nd
     tubea(i,:)=circshift(tangles,[0,-i]);
 end;
 tubea=triu(tubea);
 tubea(logical(tril(ones(size(tubea)))))=nan;
 

 imsize=size(x);
 pbd=zeros([imsize,(Nd-1)*(Nd)/2],'single');
 p2d=zeros([2,(Nd-1)*(Nd)/2],'single');
 counter=1;
 for angn=1:length(tangles)
     imsize=size(x);
     angDet=0:1/Nd:1;
     angcDet=angDet(1:end-1)*2*pi+pi/Nd;
     angDet=angDet*2*pi;
     detcoordsc=[r1*cos(angcDet);r1*sin(angcDet)];
     detcoords=[r1*cos(angDet);r1*sin(angDet)];

     a=cos(tangles(angn)+pi/2);b=sin(tangles(angn)+pi/2);c=-r1;
     dist=abs(a*detcoords(1,1:end-1)+b*detcoords(2,1:end-1)+c)/sqrt(a^2+b^2);

     distt=round(dist*100)/100;
     udist=unique(distt);
     for i=1:length(udist)
         dist(distt==udist(i))=mean(dist(distt==udist(i)));
     end;
     clear distt
     udist=unique(dist);
     tubet=diff(udist);
     distim=abs(a*x+b*y+c)/sqrt(a^2+b^2);
     distim=repmat(distim,[1,1,length(udist)-1]);
     clines=udist+[tubet,0]/2;
     clines=repmat(reshape(clines(1:end-1),1,1,[]),[imsize,1]);
     distim=abs(distim-clines);
     thr=repmat(reshape(tubet/2,1,1,[]),[imsize,1]);
     pc=distim<=thr-.5;
     po=distim>thr-.5&distim<thr+.5;
     pc=single(pc)+po.*(-distim+thr+.5);
     ttube=find(tubea==tangles(angn));
     [tubsub(:,1),tubsub(:,2)]=ind2sub([Nd,Nd],ttube);
     poidist=abs(a*detcoordsc(1,tubsub(:,1))+b*detcoordsc(2,tubsub(:,1))+c)/sqrt(a^2+b^2);
     [zzz,ind]=sort(poidist);
     tubsub=tubsub(ind,:)';
     pbd(:,:,counter:counter+size(pc,3)-1)=pc;
     p2d(:,counter:counter+size(pc,3)-1)=tubsub;
     counter=counter+size(pc,3);
     clear tubsub;
 end;
 

%      figure; hold on;
%      imagesc(coords,coords,pc(:,:,1));
%      plot(-r1:2*r1/20:r1,(-a*(-r1:2*r1/20:r1)-c)/b,'b');
%      plot(-r1:2*r1/20:r1,sqrt(r1^2-(-r1:2*r1/20:r1).^2),'g');
%      plot(-r1:2*r1/20:r1,-sqrt(r1^2-(-r1:2*r1/20:r1).^2),'g');
%      plot(detcoordsc(1,:),detcoordsc(2,:),'bx');
%      plot(detcoords(1,:),detcoords(2,:),'gx');
%      axis([-r1,r1,-r1,r1]);
return;